==> itinerary-24.02.2.tar.xz: itinerary-24.02.2/README.md <==
# KDE Itinerary

A digital travel assistant that supports you while traveling without compromising your privacy.

![KDE Itinerary timeline view](https://cdn.kde.org/screenshots/itinerary/kde-itinerary-timeline.png)

## Getting KDE Itinerary

### Flatpak

Stable flatpaks are available from [Flathub](https://flathub.org/apps/details/org.kde.itinerary).

Nightly flatpaks are available from KDE's Flatpak repository:

```
flatpak remote-add --if-not-exists kdeapps --from https://distribute.kde.org/kdeapps.flatpakrepo
flatpak install org.kde.itinerary
```

### Android

Release builds are available in KDE's [release F-Droid repository](https://cdn.kde.org/android/stable-releases/fdroid/repo/?fingerprint=13784BA6C80FF4E2181E55C56F961EED5844CEA16870D3B38D58780B85E1158F).

![Link to KDE's release F-Droid repository](doc/kde-fdroid-release-repository-link.png)

Nightly builds are available from KDE's [nightly F-Droid Repository](https://cdn.kde.org/android/fdroid/repo/?fingerprint=B3EBE10AFA6C5C400379B34473E843D686C61AE6AD33F423C98AF903F056523F).

![Link to KDE's nightly F-Droid repository](doc/kde-fdroid-release-repository-link.png)

## Contributing

General introduction: https://community.kde.org/Get_Involved

Building:
- Android: https://develop.kde.org/docs/packaging/android/building_applications/
- Othe platforms: https://community.kde.org/Get_Involved/development

Important external components:
- Travel document extractor engine: https://invent.kde.org/pim/kitinerary
- Public transport data access: https://invent.kde.org/libraries/kpublictransport
- Indoor map renderer: https://invent.kde.org/libraries/kosmindoormap

Matrix channel: [#itinerary:kde.org](https://matrix.to/#/#itinerary:kde.org)

==> itinerary-24.04.80.tar.xz: itinerary-24.04.80/README.md <==
# KDE Itinerary

A digital travel assistant that supports you while traveling without compromising your privacy.

![KDE Itinerary timeline view](https://cdn.kde.org/screenshots/itinerary/kde-itinerary-timeline.png)

## Getting KDE Itinerary

### Flatpak

Stable flatpaks are available from [Flathub](https://flathub.org/apps/details/org.kde.itinerary).

Nightly flatpaks are available from KDE's Flatpak nightly repository:

```
flatpak install https://cdn.kde.org/flatpak/itinerary-nightly/org.kde.itinerary.flatpakref
```

### Android

Release builds are available in KDE's [release F-Droid repository](https://cdn.kde.org/android/stable-releases/fdroid/repo/?fingerprint=13784BA6C80FF4E2181E55C56F961EED5844CEA16870D3B38D58780B85E1158F).

![Link to KDE's release F-Droid repository](doc/kde-fdroid-release-repository-link.png)

Nightly builds are available from KDE's [nightly F-Droid Repository](https://cdn.kde.org/android/fdroid/repo/?fingerprint=B3EBE10AFA6C5C400379B34473E843D686C61AE6AD33F423C98AF903F056523F).

![Link to KDE's nightly F-Droid repository](doc/kde-fdroid-release-repository-link.png)

## Contributing

General introduction: https://community.kde.org/Get_Involved

Building:
- Android: https://develop.kde.org/docs/packaging/android/building_applications/
- Othe platforms: https://community.kde.org/Get_Involved/development

Important external components:
- Travel document extractor engine: https://invent.kde.org/pim/kitinerary
- Public transport data access: https://invent.kde.org/libraries/kpublictransport
- Indoor map renderer: https://invent.kde.org/libraries/kosmindoormap

Matrix channel: [#itinerary:kde.org](https://matrix.to/#/#itinerary:kde.org)
